160,371 Commits over 4,566 Days - 1.46cph!

13 Days Ago
Send animal look direction in an RPC rather than with SendNetworkUpdate Animals with look animators were running network updates crazy often rather than just sending the look over This was especially bad with cows, wolfs, sheep and bulls Worst offender is cow at ~144 bytes per look update (network update). ~350 B/s per cow per player -> ~60 B/s
13 Days Ago
merge from main
13 Days Ago
Set all the gun firing effects warmed up amount accordingly Estimated +21MB vs main, still around -29MB overall after removing the 3900 useless thrown projectiles
13 Days Ago
Release pad run/crouch toggles when keyboard/mouse is used, so a pad latch can't carry into keyboard play
13 Days Ago
Various prefab fixes
13 Days Ago
Fix editor NRE debug
13 Days Ago
mag_drop_fixes -> main
13 Days Ago
Stop SpaceLR and M15 mags sticking to the bone
13 Days Ago
Gun attack effects can now be recycled before their tail sound finishes, means we only have to warm up half the amount we'd need to
13 Days Ago
Cleanup
13 Days Ago
merge from main
13 Days Ago
Skip the gamepad vehicle action set lookup when no Steam Input controller is active
13 Days Ago
Only send waterwheel network updates when its actually changed (at low speed) Saves ~76 B per skipped update per nearby player
13 Days Ago
Merge from main
13 Days Ago
Clear potential stale gamepad inventory cursors in edit mode
13 Days Ago
Tooltip bind lookup fix
13 Days Ago
Added replayInPlace to EffectRecycle, lets us flag effects that can be replayed in place instead of popping and retiring a pooled copy every time Applied to AK first and 3rd person shell eject effects for now, ~0.13ms -> ~0.04ms per shot Also means we'll only have to prewarm a handful of shell particle prefabs for all the guns
14 Days Ago
Adding dweller mace viewmodel rig
14 Days Ago
Merge from main
14 Days Ago
merge from main
14 Days Ago
Use Facepunch.Steamworks GetPngAnalogActionGlyph for stick/trigger glyphs, remove the now unnecessary hacky workaround
14 Days Ago
Merge from main
14 Days Ago
Fix motion vector pass being culled when ocean is present
14 Days Ago
Merge from main (actually latest this time)
14 Days Ago
Updating tattoo rig with updated mesh
14 Days Ago
Merge from main, and fix MapInterface marker conflict
14 Days Ago
Merge from render_pipeline_testing
14 Days Ago
Merge from render_pipeline_testing
14 Days Ago
Merge from fp_sw_glyph_fixes
14 Days Ago
Update Facepunch.Steamworks: fix Steam Input glyph origin buffer overflow, add GetPngAnalogActionGlyph, cache action set handles
14 Days Ago
Forward jump down animations for cow and sheep
14 Days Ago
Updating flail viewmodel rig
14 Days Ago
Rebind rendertarget to camera target after rendergraph and move SetupCameraProperties back
Rin
14 Days Ago
Handmade SMG damage Increased 20 > 21
14 Days Ago
▄▆▄▆▅█▋▍ ▉▋▆ ▍▉▇▅█▅▊ ▉█▍▄▇ ▆▍ ▉▇ █▆█ ▌▋▇▆▅▇▄▅▄▄ ▋▌▉▉▋ ▍▍ ▊▅▋▌ ▌▍█▆ ▄▍▌ ▇▉▅▇▊▄▌█ ▊▇▅▌▇▍▊█▊▅█▋▉▍▊▊▆▉ ▊▄▌ ▌▍▅▇▅▋▉ ▍█ ▅▉▊▇▆▊█▆▇▌▆█▋▅▉▅▇▇▍█▄▅█▌▉▋▇▄▉▆▆▅▉▆▍▍▄▅▋▄▅ ▍▆▋▋▇▄▋▉▅ ▌▇▉█▇▄▄▌ ▋▉▆█▋▄▊▅▌ ▉▆▊▅▅▊▌▆▅ ▌▊▄▆▊▊█▇ █▌▉ ▄▍▌▌▆█▅▋
14 Days Ago
Merge from car_spawning_prefill
14 Days Ago
Round up the amount of filled slots, so a 5 slot engine gets 3 prefilled instead of 2
14 Days Ago
Manifest update
14 Days Ago
Merge from main
14 Days Ago
Merge from prototype_draggable_markers Can now drag map markers on the map screen with MMB
14 Days Ago
▉▊▄▅▋▌ █▇▆▌▉█▍ ▍▄▉ ▄▄▇▋▆█▄
14 Days Ago
▉▄▊▊▌▅ ▉▇▍▅ ▄▌▊▍
14 Days Ago
Merge from terrain_watermap_test
14 Days Ago
Remove watermap texture2D creation on procedural map, saves ~89.5MB on 4k map
14 Days Ago
Merge from livestock_digestion_boost
14 Days Ago
Cleanup
14 Days Ago
Merge fixes Apply the dung boost the whole time an animal is eating an item from the trough, not just when the item is consumed (caused gaps in boost coverage) Animals eat a booster item from the trough over any other item
14 Days Ago
Merge from main (sketchy merge, need to revert any behaviour changes)
14 Days Ago
Fixed EffectParentToWeaponBone 128B alloc per effect spawn
14 Days Ago
When in first person, don't spawn effects with HideIfOwnerFirstPerson instead of spawning and hiding them right away Also fixed the 128B alloc in HideIfOwnerFirstPerson.OnEnable Saves 0.1ms when firing the AK